GlyphStyle

Struct GlyphStyle 

pub struct GlyphStyle(/* private fields */);
Defines the script and style associated with a single glyph.

Implementations

Source

impl GlyphStyle

pub const fn from_raw_parts( style_index: u16, is_non_base: bool, is_digit: bool, ) -> Self

Constructs a new glyph style from the given style index and properties.

pub const fn is_unassigned(self) -> bool

Returns true if this glyph doesn’t have an assigned style.

pub const fn is_non_base(self) -> bool

Returns true if this glyph is a non-base (usually a mark).

pub const fn is_digit(self) -> bool

Returns true if this glyph is a digit.

pub fn style_class(self) -> Option<&'static StyleClass>

Returns the associated style class for this glyph.

pub const fn style_index(self) -> Option<u16>

Returns the index of the style class for this class.