pub struct Segment { /* private fields */ }Expand description
Sequence of points with a single dominant direction.
Implementations
Sourceimpl Segment
impl Segment
Sourcepub fn score(&self) -> i32
pub fn score(&self) -> i32
Returns the computed score of the segment; used during stem matching.
Sourcepub fn length(&self) -> i32
pub fn length(&self) -> i32
Returns the computed length of the segment; used during stem matching.
Sourcepub fn link_index(&self) -> Option<u16>
pub fn link_index(&self) -> Option<u16>
Returns the index of the best candidate for a stem link.
Sourcepub fn serif_index(&self) -> Option<u16>
pub fn serif_index(&self) -> Option<u16>
Returns the index of the best candidate for a serif link.
Sourcepub fn point_indices(&self) -> (u16, u16)
pub fn point_indices(&self) -> (u16, u16)
Returns the indices of first and last points that define the segment.
Sourcepub fn edge_index(&self) -> Option<u16>
pub fn edge_index(&self) -> Option<u16>
Returns the index of edge that is associated with the segment.
Sourcepub fn next_in_edge_index(&self) -> Option<u16>
pub fn next_in_edge_index(&self) -> Option<u16>
Returns the index of next segment in the associated edge’s segment list.