pub struct GlyphStyle(/* private fields */);Expand description
Defines the script and style associated with a single glyph.
Implementations
Sourceimpl GlyphStyle
impl GlyphStyle
Sourcepub const fn from_raw_parts(
style_index: u16,
is_non_base: bool,
is_digit: bool,
) -> Self
pub const fn from_raw_parts( style_index: u16, is_non_base: bool, is_digit: bool, ) -> Self
Constructs a new glyph style from the given style index and properties.
Sourcepub const fn is_unassigned(self) -> bool
pub const fn is_unassigned(self) -> bool
Returns true if this glyph doesn’t have an assigned style.
Sourcepub const fn is_non_base(self) -> bool
pub const fn is_non_base(self) -> bool
Returns true if this glyph is a non-base (usually a mark).
Sourcepub fn style_class(self) -> Option<&'static StyleClass>
pub fn style_class(self) -> Option<&'static StyleClass>
Returns the associated style class for this glyph.
Sourcepub const fn style_index(self) -> Option<u16>
pub const fn style_index(self) -> Option<u16>
Returns the index of the style class for this class.